local M = {}

local lastY = 0

local timezone = 0

local function init()
	electrics.values['elevator'] = 0
	electrics.values['st10rpm'] = 0
	electrics.values['st10attitude'] = 0
	electrics.values['st10hdg'] = 0
	electrics.values['st10vs'] = 0
	electrics.values['st10airspeed'] = 0
	electrics.values['st10clocks'] = 0
	electrics.values['st10clockm'] = 0
	electrics.values['st10clockh'] = 0
	electrics.values['st10rudderL'] = 0
	electrics.values['st10rudderR'] = 0
end

local function reset()
	init()
end

local function updateGFX(dt)
	local turnSignals = electrics.values['turnsignal']
	
	local leftRudderPedal = 0
	local rightRudderPedal = 0
	if turnSignals < 0 then leftRudderPedal = math.abs(turnSignals) end
	if turnSignals > 0 then rightRudderPedal = turnSignals end
	
	electrics.values['st10rudderL'] = leftRudderPedal
	electrics.values['st10rudderR'] = rightRudderPedal
	
	local curPos = obj:getPosition()
	
		
	local elev = electrics.values["brake"] - electrics.values["throttle"]
	electrics.values['elevator'] = elev * -1
	
   	local dirVector = obj:getDirectionVector()
 	local dirVectorUp = obj:getDirectionVectorUp()
   	local roll = dirVectorUp.x * -dirVector.y + dirVectorUp.y * dirVector.x
	local rollProcessed = math.deg(roll) 
	electrics.values['st10attitude'] = rollProcessed * -1
	electrics.values['st10rpm'] = drivetrain.wheelInfo[3].angularVelocity
	
	electrics.values['st10hdg'] = (math.deg(obj:getDirection()) % 360)
	
	local secondFraction = dt / 1000.0
	local metersPerSecond = (lastY - curPos.z * 3.2808) * secondFraction
	local feetPerMinute = metersPerSecond * 196.850394
	
	electrics.values['st10vs'] = feetPerMinute
	
	lastY = curPos.z * 3.28083
	
	local airspeed = obj:getVelocity():length()
	electrics.values['st10airspeed']  = airspeed * 1.9438444924406
	
	local dateTime = os.date("*t", os.time())
	
	local psec = dateTime.sec/ 60
	local pmin = (dateTime.min + psec) / 60
	local ph = ((dateTime.hour % 12) + (pmin)) / 12
	
	
	--prop functions : st10clocks st10clockm st10clockh
	--prop factor should be 360
	electrics.values['st10clocks'] = psec
	electrics.values['st10clockm'] = pmin 
	electrics.values['st10clockh'] =  ph 
	
end

-- public interface
M.init      = init
M.reset     = reset
M.updateGFX = updateGFX

return M